/* ANSI-C code produced by gperf version 3.0.4 */
/* Command-line: /usr/bin/gperf -I -t -L ANSI-C -N melco_tree_lookup -T tree-hash.txt  */
/* Computed positions: -k'2-4,$' */

#if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
      && ('%' == 37) && ('&' == 38) && ('\'' == 39) && ('(' == 40) \
      && (')' == 41) && ('*' == 42) && ('+' == 43) && (',' == 44) \
      && ('-' == 45) && ('.' == 46) && ('/' == 47) && ('0' == 48) \
      && ('1' == 49) && ('2' == 50) && ('3' == 51) && ('4' == 52) \
      && ('5' == 53) && ('6' == 54) && ('7' == 55) && ('8' == 56) \
      && ('9' == 57) && (':' == 58) && (';' == 59) && ('<' == 60) \
      && ('=' == 61) && ('>' == 62) && ('?' == 63) && ('A' == 65) \
      && ('B' == 66) && ('C' == 67) && ('D' == 68) && ('E' == 69) \
      && ('F' == 70) && ('G' == 71) && ('H' == 72) && ('I' == 73) \
      && ('J' == 74) && ('K' == 75) && ('L' == 76) && ('M' == 77) \
      && ('N' == 78) && ('O' == 79) && ('P' == 80) && ('Q' == 81) \
      && ('R' == 82) && ('S' == 83) && ('T' == 84) && ('U' == 85) \
      && ('V' == 86) && ('W' == 87) && ('X' == 88) && ('Y' == 89) \
      && ('Z' == 90) && ('[' == 91) && ('\\' == 92) && (']' == 93) \
      && ('^' == 94) && ('_' == 95) && ('a' == 97) && ('b' == 98) \
      && ('c' == 99) && ('d' == 100) && ('e' == 101) && ('f' == 102) \
      && ('g' == 103) && ('h' == 104) && ('i' == 105) && ('j' == 106) \
      && ('k' == 107) && ('l' == 108) && ('m' == 109) && ('n' == 110) \
      && ('o' == 111) && ('p' == 112) && ('q' == 113) && ('r' == 114) \
      && ('s' == 115) && ('t' == 116) && ('u' == 117) && ('v' == 118) \
      && ('w' == 119) && ('x' == 120) && ('y' == 121) && ('z' == 122) \
      && ('{' == 123) && ('|' == 124) && ('}' == 125) && ('~' == 126))
/* The character set is not based on ISO-646.  */
#error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gnu-gperf@gnu.org>."
#endif


#include <melco/tree-hash.h>
unsigned int melco_tree_shortid[] = {
	0x0001,
	0x0002,
	0x0003,
	0x0004,
	0x0006,
	0x0007,
	0x0008,
	0x0009,
	0x000A,
	0x000B,
	0x000D,
	0x000E,
	0x0010,
	0x0024,
	0x0025,
	0x0027,
	0x0028,
	0x0029,
	0x002A,
	0x002B,
	0x002C,
	0x002D,
	0x002E,
	0x0030,
	0x0031,
	0x0032,
	0x0033,
	0x0034,
	0x0035,
	0x0036,
	0x0037,
	0x0038,
	0x0039,
	0x003A,
	0x003B,
	0x003C,
	0x0040,
	0x0061,
	0x00A1,
	0x00B1,
	0x00B2,
	0x00B3,
	0x0100,
	0x0101,
	0x0102,
	0x0103,
	0x0104,
	0x0105,
	0x0106,
	0x0107,
	0x0108,
	0x0109,
	0x0110,
	0x0111,
	0x0112,
	0x0113,
	0x0114,
	0x0115,
	0x0116,
	0x0117,
	0x0118,
	0x0119,
	0x0120,
	0x0121,
	0x0122,
	0x0123,
	0x0124,
	0x0125,
	0x0126,
	0x0127,
	0x0128,
	0x0129,
	0x0130,
	0x0131,
	0x0132,
	0x0133,
	0x0134,
	0x0135,
	0x0136,
	0x0137,
	0x0138,
	0x0139,
	0x0140,
	0x0141,
	0x0142,
	0x0143,
	0x0144,
	0x0145,
	0x0146,
	0x0147,
	0x0148,
	0x0149,
	0x0150,
	0x0151,
	0x0152,
	0x0153,
	0x0154,
	0x0155,
	0x0156,
	0x0157,
	0x0158,
	0x0159,
	0x0160,
	0x0161,
	0x0162,
	0x0163,
	0x0164,
	0x0165,
	0x0166,
	0x0167,
	0x0168,
	0x0169,
	0x0200,
	0x0201,
	0x0202,
	0x0203,
	0x0204,
	0x0205,
	0x0206,
	0x0207,
	0x0208,
	0x0209,
	0x0210,
	0x0211,
	0x0212,
	0x0213,
	0x0214,
	0x0215,
	0x0216,
	0x0217,
	0x0218,
	0x0219,
	0x0220,
	0x0221,
	0x0222,
	0x0223,
	0x0224,
	0x0225,
	0x0226,
	0x0227,
	0x0228,
	0x0229,
	0x0230,
	0x0231,
	0x0232,
	0x0233,
	0x0234,
	0x0235,
	0x0236,
	0x0237,
	0x0238,
	0x0239,
	0x0240,
	0x0241,
	0x0242,
	0x0243,
	0x0244,
	0x0245,
	0x0246,
	0x0247,
	0x0248,
	0x0249,
	0x0250,
	0x0251,
	0x0252,
	0x0253,
	0x0254,
	0x0255,
	0x0256,
	0x0257,
	0x0258,
	0x0259,
	0x0260,
	0x0261,
	0x0262,
	0x0263,
	0x0264,
	0x0265,
	0x0266,
	0x0267,
	0x0268,
	0x0269,
	0x0300,
	0x0301,
	0x0302,
	0x0303,
	0x0304,
	0x0305,
	0x0306,
	0x0307,
	0x0308,
	0x0309,
	0x0310,
	0x0311,
	0x0312,
	0x0313,
	0x0314,
	0x0315,
	0x0316,
	0x0317,
	0x0318,
	0x0319,
	0x0320,
	0x0321,
	0x0322,
	0x0323,
	0x0324,
	0x0325,
	0x0326,
	0x0327,
	0x0328,
	0x0329,
	0x0330,
	0x0331,
	0x0332,
	0x0333,
	0x0334,
	0x0335,
	0x0336,
	0x0337,
	0x0338,
	0x0339,
	0x0340,
	0x0341,
	0x0342,
	0x0343,
	0x0344,
	0x0345,
	0x0346,
	0x0347,
	0x0348,
	0x0349,
	0x0350,
	0x0351,
	0x0352,
	0x0353,
	0x0354,
	0x0355,
	0x0356,
	0x0357,
	0x0358,
	0x0359,
	0x0360,
	0x0361,
	0x0362,
	0x0363,
	0x0364,
	0x0365,
	0x0366,
	0x0367,
	0x0368,
	0x0369,
	0x0400,
	0x0401,
	0x0402,
	0x0403,
	0x0404,
	0x0405,
	0x0406,
	0x0407,
	0x0408,
	0x0409,
	0x0410,
	0x0411,
	0x0412,
	0x0413,
	0x0414,
	0x0415,
	0x0416,
	0x0417,
	0x0418,
	0x0419,
	0x0420,
	0x0421,
	0x0422,
	0x0423,
	0x0424,
	0x0425,
	0x0426,
	0x0427,
	0x0428,
	0x0429,
	0x0430,
	0x0431,
	0x0432,
	0x0433,
	0x0434,
	0x0435,
	0x0436,
	0x0437,
	0x0438,
	0x0439,
	0x0440,
	0x0441,
	0x0442,
	0x0443,
	0x0444,
	0x0445,
	0x0446,
	0x0447,
	0x0448,
	0x0449,
	0x0450,
	0x0451,
	0x0452,
	0x0453,
	0x0454,
	0x0455,
	0x0456,
	0x0457,
	0x0458,
	0x0459,
	0x0460,
	0x0461,
	0x0462,
	0x0463,
	0x0464,
	0x0465,
	0x0466,
	0x0467,
	0x0468,
	0x0469,
	0x0500,
	0x0501,
	0x0502,
	0x0503,
	0x0504,
	0x0505,
	0x0506,
	0x0507,
	0x0508,
	0x0509,
	0x0510,
	0x0511,
	0x0512,
	0x0513,
	0x0514,
	0x0515,
	0x0516,
	0x0517,
	0x0518,
	0x0519,
	0x0520,
	0x0521,
	0x0522,
	0x0523,
	0x0524,
	0x0525,
	0x0526,
	0x0527,
	0x0528,
	0x0529,
	0x0530,
	0x0531,
	0x0532,
	0x0533,
	0x0534,
	0x0535,
	0x0536,
	0x0537,
	0x0538,
	0x0539,
	0x0540,
	0x0541,
	0x0542,
	0x0543,
	0x0544,
	0x0545,
	0x0546,
	0x0547,
	0x0548,
	0x0549,
	0x0550,
	0x0551,
	0x0552,
	0x0553,
	0x0554,
	0x0555,
	0x0556,
	0x0557,
	0x0558,
	0x0559,
	0x0560,
	0x0561,
	0x0562,
	0x0563,
	0x0564,
	0x0565,
	0x0566,
	0x0567,
	0x0568,
	0x0569,
	0x0600,
	0x0601,
	0x0602,
	0x0603,
	0x0604,
	0x0605,
	0x0606,
	0x0607,
	0x0608,
	0x0609,
	0x0610,
	0x0611,
	0x0612,
	0x0613,
	0x0614,
	0x0615,
	0x0616,
	0x0617,
	0x0618,
	0x0619,
	0x0620,
	0x0621,
	0x0622,
	0x0623,
	0x0624,
	0x0625,
	0x0626,
	0x0627,
	0x0628,
	0x0629,
	0x0630,
	0x0631,
	0x0632,
	0x0633,
	0x0634,
	0x0635,
	0x0636,
	0x0637,
	0x0638,
	0x0639,
	0x0640,
	0x0641,
	0x0642,
	0x0643,
	0x0644,
	0x0645,
	0x0646,
	0x0647,
	0x0648,
	0x0649,
	0x0650,
	0x0651,
	0x0652,
	0x0653,
	0x0654,
	0x0655,
	0x0656,
	0x0657,
	0x0658,
	0x0659,
	0x0660,
	0x0661,
	0x0662,
	0x0663,
	0x0664,
	0x0665,
	0x0666,
	0x0667,
	0x0668,
	0x0669,
	0x0700,
	0x0701,
	0x0702,
	0x0703,
	0x0704,
	0x0705,
	0x0706,
	0x0707,
	0x0708,
	0x0709,
	0x0710,
	0x0711,
	0x0712,
	0x0713,
	0x0714,
	0x0715,
	0x0716,
	0x0717,
	0x0718,
	0x0719,
	0x0720,
	0x0721,
	0x0722,
	0x0723,
	0x0724,
	0x0725,
	0x0726,
	0x0727,
	0x0728,
	0x0729,
	0x0730,
	0x0731,
	0x0732,
	0x0733,
	0x0734,
	0x0735,
	0x0736,
	0x0737,
	0x0738,
	0x0739,
	0x0740,
	0x0741,
	0x0742,
	0x0743,
	0x0744,
	0x0745,
	0x0746,
	0x0747,
	0x0748,
	0x0749,
	0x0750,
	0x0751,
	0x0752,
	0x0753,
	0x0754,
	0x0755,
	0x0756,
	0x0757,
	0x0758,
	0x0759,
	0x0760,
	0x0761,
	0x0762,
	0x0763,
	0x0764,
	0x0765,
	0x0766,
	0x0767,
	0x0768,
	0x0769,
	0x0800,
	0x0801,
	0x0802,
	0x0803,
	0x0804,
	0x0805,
	0x0806,
	0x0807,
	0x0808,
	0x0809,
	0x0810,
	0x0811,
	0x0812,
	0x0813,
	0x0814,
	0x0815,
	0x0816,
	0x0817,
	0x0818,
	0x0819,
	0x0820,
	0x0821,
	0x0822,
	0x0823,
	0x0824,
	0x0825,
	0x0826,
	0x0827,
	0x0828,
	0x0829,
	0x0830,
	0x0831,
	0x0832,
	0x0833,
	0x0834,
	0x0835,
	0x0836,
	0x0837,
	0x0838,
	0x0839,
	0x0840,
	0x0841,
	0x0842,
	0x0843,
	0x0844,
	0x0845,
	0x0846,
	0x0847,
	0x0848,
	0x0849,
	0x0850,
	0x0851,
	0x0852,
	0x0853,
	0x0854,
	0x0855,
	0x0856,
	0x0857,
	0x0858,
	0x0859,
	0x0860,
	0x0861,
	0x0862,
	0x0863,
	0x0864,
	0x0865,
	0x0866,
	0x0867,
	0x0868,
	0x0869,
	0x0001,
	0x0002,
	0x0003,
	0x0004,
	0x0006,
	0x0007,
	0x0008,
	0x0009,
	0x000C,
	0x000D,
	0x000E,
	0x0010,
	0x0027,
	0x0028,
	0x0029,
	0x002A,
	0x002B,
	0x002C,
	0x002D,
	0x002E,
	0x0030,
	0x0031,
	0x0032,
	0x0036,
	0x0037,
	0x0038,
	0x0039,
	0x003A,
	0x003B,
	0x0051,
	0x0061,
	0x00A1,
	0x00B1,
	0x00B2,
	0x00B2,
	0x00B3,
	0x0001,
	0x0002,
	0x0004,
	0x0028,
	0x0036,
	0x00A1,
	0x00B1,
};
char *melco_tree_type[] = {
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"E",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L",
	"L2",
	"L3",
	"L",
	"S",
	"S",
	"S",
	"S",
	"S",
	"S",
	"S",
};
#include <string.h>

#define TOTAL_KEYWORDS 645
#define MIN_WORD_LENGTH 5
#define MAX_WORD_LENGTH 6
#define MIN_HASH_VALUE 80
#define MAX_HASH_VALUE 4184
/* maximum key range = 4105, duplicates = 0 */

#ifdef __GNUC__
__inline
#else
#ifdef __cplusplus
inline
#endif
#endif
static unsigned int
hash (register const char *str, register unsigned int len)
{
  static unsigned short asso_values[] =
    {
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,    5,   16,
        10,    0,  911,  750,  260, 4185, 4185, 4185, 4185, 4185,
      4185, 1924,  165,  295,  747,  590,  220, 1871,  112,   90,
         1,   45, 1254,  247,  351,  865,   30,  590,   15,    0,
       470,  395,  365,  655, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185,
      4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185, 4185
    };
  return len + asso_values[(unsigned char)str[3]+13] + asso_values[(unsigned char)str[2]] + asso_values[(unsigned char)str[1]+23] + asso_values[(unsigned char)str[len - 1]];
}

#ifdef __GNUC__
__inline
#if defined __GNUC_STDC_INLINE__ || defined __GNUC_GNU_INLINE__
__attribute__ ((__gnu_inline__))
#endif
#endif
struct melco_tree_s *
melco_tree_lookup (register const char *str, register unsigned int len)
{
  static struct melco_tree_s wordlist[] =
    {
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"003BL", 236, 630},
      {"0039L", 78, 628},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0009L", 7, 609},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"002BL", 192, 618},
      {"0029L", 18, 616},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"003AL", 132, 629},
      {"0839E", 4, 571},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0809E", 4, 541},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"002AL", 480, 617},
      {"0829E", 4, 561},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0739E", 4, 501},
      {"0819E", 4, 551},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0709E", 4, 471},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0729E", 4, 491},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0539E", 4, 361},
      {"0719E", 4, 481},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0509E", 4, 331},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0529E", 4, 351},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"003BE", 192, 34},
      {"0039E", 25, 32},
      {"0519E", 4, 341},
      {"",0,0}, {"",0,0},
      {"000BE", 50, 9},
      {"0009E", 100, 7},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"002BE", 64, 19},
      {"0029E", 6, 17},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"003AE", 68, 33},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"000AE", 11, 8},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"002AE", 160, 18},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0038L", 36, 627},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0008L", 26, 608},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0028L", 24, 615},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0838E", 4, 570},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0808E", 4, 540},
      {"",0,0},
      {"0037L", 156, 626},
      {"",0,0}, {"",0,0},
      {"0828E", 4, 560},
      {"",0,0},
      {"0007L", 64, 607},
      {"",0,0}, {"",0,0},
      {"0738E", 4, 500},
      {"0818E", 4, 550},
      {"0027L", 72, 614},
      {"",0,0}, {"",0,0},
      {"0708E", 4, 470},
      {"",0,0},
      {"0837E", 4, 569},
      {"",0,0}, {"",0,0},
      {"0728E", 4, 490},
      {"",0,0},
      {"0807E", 4, 539},
      {"",0,0}, {"",0,0},
      {"0538E", 4, 360},
      {"0718E", 4, 480},
      {"0827E", 4, 559},
      {"",0,0}, {"",0,0},
      {"0508E", 4, 330},
      {"",0,0},
      {"0737E", 4, 499},
      {"0817E", 4, 549},
      {"",0,0},
      {"0528E", 4, 350},
      {"",0,0},
      {"0707E", 4, 469},
      {"",0,0}, {"",0,0},
      {"0038E", 9, 31},
      {"0518E", 4, 340},
      {"0727E", 4, 489},
      {"",0,0}, {"",0,0},
      {"0008E", 10, 6},
      {"",0,0},
      {"0537E", 4, 359},
      {"0717E", 4, 479},
      {"",0,0},
      {"0028E", 53, 16},
      {"",0,0},
      {"0507E", 4, 329},
      {"",0,0}, {"",0,0},
      {"0031L", 72, 623},
      {"",0,0},
      {"0527E", 4, 349},
      {"",0,0}, {"",0,0},
      {"0001L", 84, 602},
      {"",0,0},
      {"0037E", 31, 30},
      {"0517E", 4, 339},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0007E", 162, 5},
      {"",0,0}, {"",0,0},
      {"0831E", 4, 563},
      {"",0,0},
      {"0027E", 54, 15},
      {"",0,0}, {"",0,0},
      {"0801E", 4, 533},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0821E", 4, 553},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0731E", 4, 493},
      {"0811E", 4, 543},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0701E", 4, 463},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0721E", 4, 483},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0531E", 4, 353},
      {"0711E", 4, 473},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0501E", 4, 323},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0521E", 4, 343},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0031E", 10, 24},
      {"0511E", 4, 333},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0001E", 49, 0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0835E", 4, 567},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0805E", 4, 537},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0825E", 4, 557},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0735E", 4, 497},
      {"0815E", 4, 547},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0705E", 4, 467},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0725E", 4, 487},
      {"",0,0}, {"",0,0},
      {"0239E", 4, 151},
      {"",0,0},
      {"0535E", 4, 357},
      {"0715E", 4, 477},
      {"",0,0},
      {"0209E", 4, 121},
      {"",0,0},
      {"0505E", 4, 327},
      {"",0,0}, {"",0,0},
      {"0229E", 4, 141},
      {"",0,0},
      {"0525E", 4, 347},
      {"0869E", 4, 601},
      {"",0,0}, {"",0,0},
      {"0219E", 4, 131},
      {"0035E", 22, 28},
      {"0515E", 4, 337},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0025E", 36, 14},
      {"0769E", 4, 531},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0032L", 120, 624},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0002L", 264, 603},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0569E", 4, 391},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0832E", 4, 564},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0802E", 4, 534},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0822E", 4, 554},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0732E", 4, 494},
      {"0812E", 4, 544},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0702E", 4, 464},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0722E", 4, 484},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0532E", 4, 354},
      {"0712E", 4, 474},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0502E", 4, 324},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0522E", 4, 344},
      {"",0,0},
      {"0238E", 4, 150},
      {"",0,0}, {"",0,0},
      {"0032E", 33, 25},
      {"0512E", 4, 334},
      {"0208E", 4, 120},
      {"",0,0}, {"",0,0},
      {"0002E", 240, 1},
      {"",0,0},
      {"0228E", 4, 140},
      {"",0,0}, {"",0,0},
      {"0868E", 4, 600},
      {"",0,0},
      {"0339E", 4, 221},
      {"0218E", 4, 130},
      {"",0,0},
      {"000EL", 60, 612},
      {"",0,0},
      {"0309E", 4, 191},
      {"",0,0},
      {"0237E", 4, 149},
      {"002EL", 10, 621},
      {"",0,0},
      {"0329E", 4, 211},
      {"",0,0},
      {"0207E", 4, 119},
      {"0768E", 4, 530},
      {"",0,0}, {"",0,0},
      {"0319E", 4, 201},
      {"0227E", 4, 139},
      {"00B1L", 134, 634},
      {"",0,0},
      {"0867E", 4, 599},
      {"",0,0}, {"",0,0},
      {"0217E", 4, 129},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0568E", 4, 390},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"000DL", 120, 611},
      {"",0,0},
      {"0767E", 4, 529},
      {"",0,0}, {"",0,0},
      {"002DL", 132, 620},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0567E", 4, 389},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0061L", 192, 632},
      {"",0,0},
      {"0231E", 4, 143},
      {"",0,0}, {"",0,0},
      {"000EE", 76, 11},
      {"",0,0},
      {"0201E", 4, 113},
      {"",0,0}, {"",0,0},
      {"002EE", 1, 22},
      {"",0,0},
      {"0221E", 4, 133},
      {"",0,0}, {"",0,0},
      {"0861E", 4, 593},
      {"",0,0}, {"",0,0},
      {"0211E", 4, 123},
      {"",0,0},
      {"00B1E", 159, 39},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0761E", 4, 523},
      {"0338E", 4, 220},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"000DE", 30, 10},
      {"0308E", 4, 190},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"002DE", 44, 21},
      {"0328E", 4, 210},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0561E", 4, 383},
      {"",0,0},
      {"0318E", 4, 200},
      {"",0,0}, {"",0,0},
      {"000CL", 48, 610},
      {"",0,0}, {"",0,0},
      {"0337E", 4, 219},
      {"",0,0},
      {"002CL", 540, 619},
      {"",0,0},
      {"0235E", 4, 147},
      {"0307E", 4, 189},
      {"",0,0},
      {"0061E", 27, 37},
      {"00B2L3", 1100, 636},
      {"0205E", 4, 117},
      {"0327E", 4, 209},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0225E", 4, 137},
      {"",0,0},
      {"0317E", 4, 199},
      {"0865E", 4, 597},
      {"00B2L2", 1160, 635},
      {"",0,0},
      {"0215E", 4, 127},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0765E", 4, 527},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0269E", 4, 181},
      {"",0,0},
      {"0565E", 4, 387},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"003CE", 35, 35},
      {"0331E", 4, 213},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0301E", 4, 183},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"002CE", 180, 20},
      {"0321E", 4, 203},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0311E", 4, 193},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0232E", 4, 144},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0202E", 4, 114},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0222E", 4, 134},
      {"",0,0}, {"",0,0},
      {"0862E", 4, 594},
      {"",0,0}, {"",0,0},
      {"0212E", 4, 124},
      {"",0,0},
      {"00B2E", 1100, 40},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0762E", 4, 524},
      {"0335E", 4, 217},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0305E", 4, 187},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0004L", 108, 605},
      {"0325E", 4, 207},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0562E", 4, 384},
      {"",0,0},
      {"0315E", 4, 197},
      {"",0,0}, {"",0,0},
      {"0834E", 4, 566},
      {"0639E", 4, 431},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0804E", 4, 536},
      {"0609E", 4, 401},
      {"0268E", 4, 180},
      {"",0,0}, {"",0,0},
      {"0824E", 4, 556},
      {"0629E", 4, 421},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0734E", 4, 496},
      {"0814E", 4, 546},
      {"0619E", 4, 411},
      {"",0,0}, {"",0,0},
      {"0704E", 4, 466},
      {"",0,0},
      {"0369E", 4, 251},
      {"",0,0}, {"",0,0},
      {"0724E", 4, 486},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0267E", 4, 179},
      {"0534E", 4, 356},
      {"0714E", 4, 476},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0504E", 4, 326},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0524E", 4, 346},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0034E", 23, 27},
      {"0514E", 4, 336},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0004E", 42, 3},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0024E", 96, 13},
      {"0332E", 4, 214},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0302E", 4, 184},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0322E", 4, 204},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0312E", 4, 194},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0261E", 4, 173},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0638E", 4, 430},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0608E", 4, 400},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0628E", 4, 420},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0618E", 4, 410},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0368E", 4, 250},
      {"0637E", 4, 429},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0607E", 4, 399},
      {"",0,0}, {"",0,0},
      {"0028S", 60, 641},
      {"",0,0},
      {"0627E", 4, 419},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0617E", 4, 409},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0367E", 4, 249},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0265E", 4, 177},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0003L", 198, 604},
      {"",0,0}, {"",0,0},
      {"00A1L", 260, 633},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0833E", 4, 565},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0859E", 4, 591},
      {"0803E", 4, 535},
      {"",0,0}, {"",0,0},
      {"0631E", 4, 423},
      {"",0,0},
      {"0823E", 4, 555},
      {"",0,0}, {"",0,0},
      {"0601E", 4, 393},
      {"",0,0},
      {"0733E", 4, 495},
      {"0813E", 4, 545},
      {"",0,0},
      {"0621E", 4, 413},
      {"0759E", 4, 521},
      {"0703E", 4, 465},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0611E", 4, 403},
      {"0723E", 4, 485},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0361E", 4, 243},
      {"0533E", 4, 355},
      {"0713E", 4, 475},
      {"",0,0},
      {"0001S", 18, 638},
      {"0559E", 4, 381},
      {"0503E", 4, 325},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0523E", 4, 345},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0033E", 53, 26},
      {"0513E", 4, 335},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0003E", 96, 2},
      {"",0,0}, {"",0,0},
      {"00A1E", 1557, 38},
      {"",0,0},
      {"0262E", 4, 174},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0635E", 4, 427},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0605E", 4, 397},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0625E", 4, 417},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0615E", 4, 407},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0365E", 4, 247},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0234E", 4, 146},
      {"",0,0}, {"",0,0},
      {"0858E", 4, 590},
      {"",0,0},
      {"0204E", 4, 116},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0224E", 4, 136},
      {"",0,0}, {"",0,0},
      {"0864E", 4, 596},
      {"0669E", 4, 461},
      {"",0,0},
      {"0214E", 4, 126},
      {"",0,0},
      {"0758E", 4, 520},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0857E", 4, 589},
      {"",0,0}, {"",0,0},
      {"0764E", 4, 526},
      {"0439E", 4, 291},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0558E", 4, 380},
      {"0409E", 4, 261},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0429E", 4, 281},
      {"0757E", 4, 519},
      {"",0,0}, {"",0,0},
      {"0564E", 4, 386},
      {"",0,0},
      {"0419E", 4, 271},
      {"",0,0}, {"",0,0},
      {"0632E", 4, 424},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0602E", 4, 394},
      {"",0,0},
      {"0557E", 4, 379},
      {"",0,0}, {"",0,0},
      {"0622E", 4, 414},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0051L", 26, 631},
      {"0612E", 4, 404},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0362E", 4, 244},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0002S", 60, 639},
      {"",0,0},
      {"0849E", 4, 581},
      {"",0,0}, {"",0,0},
      {"0851E", 4, 583},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0749E", 4, 511},
      {"",0,0}, {"",0,0},
      {"0751E", 4, 513},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0668E", 4, 460},
      {"0334E", 4, 216},
      {"0549E", 4, 371},
      {"",0,0}, {"",0,0},
      {"0551E", 4, 373},
      {"0304E", 4, 186},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0324E", 4, 206},
      {"00B3L", 192, 637},
      {"",0,0}, {"",0,0},
      {"0438E", 4, 290},
      {"",0,0},
      {"0314E", 4, 196},
      {"",0,0}, {"",0,0},
      {"0408E", 4, 260},
      {"",0,0},
      {"0667E", 4, 459},
      {"",0,0}, {"",0,0},
      {"0428E", 4, 280},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0855E", 4, 587},
      {"0418E", 4, 270},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0437E", 4, 289},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0407E", 4, 259},
      {"",0,0}, {"",0,0},
      {"0755E", 4, 517},
      {"",0,0},
      {"0427E", 4, 279},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0417E", 4, 269},
      {"0233E", 4, 145},
      {"00B1S", 118, 644},
      {"",0,0}, {"",0,0},
      {"0259E", 4, 171},
      {"0203E", 4, 115},
      {"0555E", 4, 377},
      {"0848E", 4, 580},
      {"",0,0}, {"",0,0},
      {"0223E", 4, 135},
      {"",0,0}, {"",0,0},
      {"0863E", 4, 595},
      {"",0,0}, {"",0,0},
      {"0213E", 4, 125},
      {"",0,0},
      {"00B3E", 74, 41},
      {"",0,0}, {"",0,0},
      {"0661E", 4, 453},
      {"0748E", 4, 510},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0763E", 4, 525},
      {"0847E", 4, 579},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0431E", 4, 283},
      {"0548E", 4, 370},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0401E", 4, 253},
      {"",0,0},
      {"0563E", 4, 385},
      {"0747E", 4, 509},
      {"",0,0},
      {"0421E", 4, 273},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0852E", 4, 584},
      {"0411E", 4, 263},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0547E", 4, 369},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0752E", 4, 514},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0665E", 4, 457},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0552E", 4, 374},
      {"0841E", 4, 573},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0435E", 4, 287},
      {"",0,0},
      {"0258E", 4, 170},
      {"",0,0}, {"",0,0},
      {"0405E", 4, 257},
      {"0741E", 4, 503},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0425E", 4, 277},
      {"",0,0},
      {"0264E", 4, 176},
      {"0333E", 4, 215},
      {"",0,0}, {"",0,0},
      {"0415E", 4, 267},
      {"0359E", 4, 241},
      {"0303E", 4, 185},
      {"",0,0}, {"",0,0},
      {"0541E", 4, 363},
      {"",0,0},
      {"0323E", 4, 205},
      {"0257E", 4, 169},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0313E", 4, 195},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0469E", 4, 321},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0845E", 4, 577},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0662E", 4, 454},
      {"0745E", 4, 507},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0249E", 4, 161},
      {"0432E", 4, 284},
      {"0545E", 4, 367},
      {"0251E", 4, 163},
      {"",0,0}, {"",0,0},
      {"0402E", 4, 254},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0422E", 4, 274},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0412E", 4, 264},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0634E", 4, 426},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0604E", 4, 396},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0624E", 4, 416},
      {"0358E", 4, 240},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0614E", 4, 406},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0364E", 4, 246},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0004S", 13, 640},
      {"0842E", 4, 574},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0357E", 4, 239},
      {"",0,0},
      {"0468E", 4, 320},
      {"",0,0},
      {"0255E", 4, 167},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0742E", 4, 504},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0542E", 4, 364},
      {"0467E", 4, 319},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0248E", 4, 160},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0263E", 4, 175},
      {"0139E", 4, 81},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0109E", 4, 51},
      {"",0,0}, {"",0,0},
      {"0349E", 4, 231},
      {"",0,0},
      {"0129E", 4, 71},
      {"0351E", 4, 233},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0247E", 4, 159},
      {"0119E", 4, 61},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0461E", 4, 313},
      {"",0,0},
      {"0252E", 4, 164},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0355E", 4, 237},
      {"",0,0},
      {"0241E", 4, 153},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0633E", 4, 425},
      {"",0,0}, {"",0,0},
      {"0854E", 4, 586},
      {"0659E", 4, 451},
      {"0603E", 4, 395},
      {"",0,0},
      {"0138E", 4, 80},
      {"0465E", 4, 317},
      {"",0,0},
      {"0623E", 4, 415},
      {"",0,0},
      {"0108E", 4, 50},
      {"",0,0}, {"",0,0},
      {"0348E", 4, 230},
      {"0613E", 4, 405},
      {"0128E", 4, 70},
      {"0754E", 4, 516},
      {"",0,0}, {"",0,0},
      {"0363E", 4, 245},
      {"",0,0},
      {"0118E", 4, 60},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"00A1S", 150, 643},
      {"0137E", 4, 79},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0554E", 4, 376},
      {"0107E", 4, 49},
      {"",0,0}, {"",0,0},
      {"0347E", 4, 229},
      {"",0,0},
      {"0127E", 4, 69},
      {"",0,0},
      {"0245E", 4, 157},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0117E", 4, 59},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0352E", 4, 234},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0131E", 4, 73},
      {"0462E", 4, 314},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0101E", 4, 43},
      {"",0,0}, {"",0,0},
      {"0341E", 4, 223},
      {"",0,0},
      {"0121E", 4, 63},
      {"0658E", 4, 450},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0111E", 4, 53},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0664E", 4, 456},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0657E", 4, 449},
      {"0242E", 4, 154},
      {"",0,0},
      {"0434E", 4, 286},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0404E", 4, 256},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0424E", 4, 276},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0414E", 4, 266},
      {"",0,0}, {"",0,0},
      {"0135E", 4, 77},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0105E", 4, 47},
      {"",0,0}, {"",0,0},
      {"0345E", 4, 227},
      {"",0,0},
      {"0125E", 4, 67},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0115E", 4, 57},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0853E", 4, 585},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0844E", 4, 576},
      {"0649E", 4, 441},
      {"",0,0}, {"",0,0},
      {"0651E", 4, 443},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0753E", 4, 515},
      {"",0,0}, {"",0,0},
      {"0169E", 4, 111},
      {"0744E", 4, 506},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0553E", 4, 375},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0544E", 4, 366},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0132E", 4, 74},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0102E", 4, 44},
      {"",0,0}, {"",0,0},
      {"0342E", 4, 224},
      {"",0,0},
      {"0122E", 4, 64},
      {"0655E", 4, 447},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0112E", 4, 54},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0254E", 4, 166},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0648E", 4, 440},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0663E", 4, 455},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0168E", 4, 110},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0433E", 4, 285},
      {"0647E", 4, 439},
      {"",0,0}, {"",0,0},
      {"0459E", 4, 311},
      {"0403E", 4, 255},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0423E", 4, 275},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0167E", 4, 109},
      {"",0,0},
      {"0413E", 4, 265},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0652E", 4, 444},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0843E", 4, 575},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0641E", 4, 433},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0743E", 4, 505},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0161E", 4, 103},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0543E", 4, 365},
      {"",0,0}, {"",0,0},
      {"0354E", 4, 236},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0458E", 4, 310},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0464E", 4, 316},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0645E", 4, 437},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0457E", 4, 309},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0165E", 4, 107},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0253E", 4, 165},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0244E", 4, 156},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0449E", 4, 301},
      {"",0,0}, {"",0,0},
      {"0451E", 4, 303},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0642E", 4, 434},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0162E", 4, 104},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0455E", 4, 307},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0134E", 4, 76},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0353E", 4, 235},
      {"0104E", 4, 46},
      {"",0,0}, {"",0,0},
      {"0344E", 4, 226},
      {"",0,0},
      {"0124E", 4, 66},
      {"",0,0},
      {"0036L", 90, 625},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0114E", 4, 56},
      {"0006L", 86, 606},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0448E", 4, 300},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0836E", 4, 568},
      {"0463E", 4, 315},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0806E", 4, 538},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0826E", 4, 558},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0736E", 4, 498},
      {"0816E", 4, 548},
      {"0447E", 4, 299},
      {"",0,0}, {"",0,0},
      {"0706E", 4, 468},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0726E", 4, 488},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0536E", 4, 358},
      {"0716E", 4, 478},
      {"",0,0}, {"",0,0},
      {"0243E", 4, 155},
      {"0506E", 4, 328},
      {"",0,0}, {"",0,0},
      {"0030L", 222, 622},
      {"0452E", 4, 304},
      {"0526E", 4, 348},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0036E", 40, 29},
      {"0516E", 4, 338},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0006E", 120, 4},
      {"",0,0}, {"",0,0},
      {"0830E", 4, 562},
      {"0010L", 111, 613},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0800E", 4, 532},
      {"0654E", 4, 446},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0820E", 4, 552},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0730E", 4, 492},
      {"0810E", 4, 542},
      {"0441E", 4, 293},
      {"",0,0}, {"",0,0},
      {"0700E", 4, 462},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0720E", 4, 482},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0530E", 4, 352},
      {"0710E", 4, 472},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0500E", 4, 322},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0520E", 4, 342},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0030E", 78, 23},
      {"0510E", 4, 332},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0010E", 33, 12},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0445E", 4, 297},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0133E", 4, 75},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0159E", 4, 101},
      {"0103E", 4, 45},
      {"",0,0}, {"",0,0},
      {"0343E", 4, 225},
      {"",0,0},
      {"0123E", 4, 65},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0113E", 4, 55},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0442E", 4, 294},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0653E", 4, 445},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0644E", 4, 436},
      {"",0,0}, {"",0,0},
      {"0158E", 4, 100},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0164E", 4, 106},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0157E", 4, 99},
      {"",0,0},
      {"0236E", 4, 148},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0206E", 4, 118},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0226E", 4, 138},
      {"",0,0}, {"",0,0},
      {"0866E", 4, 598},
      {"",0,0}, {"",0,0},
      {"0216E", 4, 128},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0766E", 4, 528},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0566E", 4, 388},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0149E", 4, 91},
      {"",0,0}, {"",0,0},
      {"0151E", 4, 93},
      {"",0,0},
      {"0230E", 4, 142},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0200E", 4, 112},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0220E", 4, 132},
      {"",0,0}, {"",0,0},
      {"0860E", 4, 592},
      {"",0,0}, {"",0,0},
      {"0210E", 4, 122},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0760E", 4, 522},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0454E", 4, 306},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0560E", 4, 382},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0336E", 4, 218},
      {"",0,0},
      {"0155E", 4, 97},
      {"",0,0}, {"",0,0},
      {"0306E", 4, 188},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0326E", 4, 208},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0316E", 4, 198},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0643E", 4, 435},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0148E", 4, 90},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0163E", 4, 105},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0330E", 4, 212},
      {"",0,0},
      {"0147E", 4, 89},
      {"",0,0}, {"",0,0},
      {"0300E", 4, 182},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0320E", 4, 202},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0310E", 4, 192},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0152E", 4, 94},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0141E", 4, 83},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0453E", 4, 305},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0444E", 4, 296},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0266E", 4, 178},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0145E", 4, 87},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0260E", 4, 172},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0142E", 4, 84},
      {"0636E", 4, 428},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0606E", 4, 398},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0626E", 4, 418},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0616E", 4, 408},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0036S", 13, 642},
      {"0366E", 4, 248},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0630E", 4, 422},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0600E", 4, 392},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0443E", 4, 295},
      {"0620E", 4, 412},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0610E", 4, 402},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0360E", 4, 242},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0154E", 4, 96},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0856E", 4, 588},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0756E", 4, 518},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0556E", 4, 378},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0850E", 4, 582},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0750E", 4, 512},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0550E", 4, 372},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0666E", 4, 458},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0436E", 4, 288},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0406E", 4, 258},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0426E", 4, 278},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0153E", 4, 95},
      {"0416E", 4, 268},
      {"",0,0}, {"",0,0},
      {"0144E", 4, 86},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0660E", 4, 452},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0846E", 4, 578},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0430E", 4, 282},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0400E", 4, 252},
      {"",0,0}, {"",0,0},
      {"0746E", 4, 508},
      {"",0,0},
      {"0420E", 4, 272},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0410E", 4, 262},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0546E", 4, 368},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0840E", 4, 572},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0740E", 4, 502},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0540E", 4, 362},
      {"",0,0}, {"",0,0},
      {"0256E", 4, 168},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0040E", 1000, 36},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0143E", 4, 85},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0250E", 4, 162},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0356E", 4, 238},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0466E", 4, 318},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0350E", 4, 232},
      {"",0,0}, {"",0,0}, {"",0,0},
      {"0246E", 4, 158},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0460E", 4, 312},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0240E", 4, 152},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0136E", 4, 78},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0106E", 4, 48},
      {"",0,0}, {"",0,0},
      {"0346E", 4, 228},
      {"",0,0},
      {"0126E", 4, 68},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0116E", 4, 58},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0130E", 4, 72},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0100E", 4, 42},
      {"",0,0}, {"",0,0},
      {"0340E", 4, 222},
      {"",0,0},
      {"0120E", 4, 62},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0110E", 4, 52},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0},
      {"0656E", 4, 448},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0650E", 4, 442},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0646E", 4, 438},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0166E", 4, 108},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0640E", 4, 432},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0160E", 4, 102},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0456E", 4, 308},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0450E", 4, 302},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0446E", 4, 298},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0440E", 4, 292},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"0156E", 4, 98},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0150E", 4, 92},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0146E", 4, 88},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0}, {"",0,0},
      {"",0,0}, {"",0,0},
      {"0140E", 4, 82}
    };

  if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
    {
      register int key = hash (str, len);

      if (key <= MAX_HASH_VALUE && key >= 0)
        {
          register const char *s = wordlist[key].name;

          if (*str == *s && !strcmp (str + 1, s + 1))
            return &wordlist[key];
        }
    }
  return 0;
}
